@@ -3,9 +3,8 @@ The test suite has some dependencies that aren't necessarily required for the
 blingalytics package itself:
 
 * You should have postgresql installed, with a "bling" user whose password is
-  set to "bling", and a database named "bling" owned by "bling". 
-* You need the following Python packages installed: mock, sqlalchemy, elixir,
-  and psycopg2.
+  set to "bling", and a database named "bling" owned by "bling".
+* You need the following Python packages installed: mock, django and psycopg2.
 
 To run the tests, simply run this file::
 
@@ -28,15 +27,16 @@ if __name__ == '__main__':
     test_dir = os.path.dirname(os.path.abspath(__file__))
     package_dir = os.path.normpath(os.path.join(test_dir, os.pardir, 'blingalytics'))
     sys.path = [test_dir, package_dir] + sys.path
+    os.environ['DJANGO_SETTINGS_MODULE'] = 'support_django.settings'
 
     suite = unittest.TestLoader().loadTestsFromNames([
         'test_base',
         'test_helpers',
+        'caches.test_redis_cache',
         'sources.test_base',
         'sources.test_derived',
         'sources.test_django_orm',
-        'sources.test_merge',
-        'sources.test_sqlalchemy_orm',
+        # 'sources.test_merge',
         'sources.test_static',
     ])
     result = unittest.TextTestRunner(verbosity=1).run(suite)
